package com.example.duplicate.service.impl;


import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.example.duplicate.controller.vo.*;
import com.example.duplicate.infrastructure.configOneDao.CommomtableMapper;
import com.example.duplicate.infrastructure.configOneDao.QualityMapper;
import com.example.duplicate.service.DuplicateService;
import com.lowagie.text.Document;
import com.lowagie.text.DocumentException;
import com.lowagie.text.Image;
import com.lowagie.text.PageSize;
import com.lowagie.text.pdf.PdfWriter;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import javax.swing.*;
import java.io.*;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @ClassName DuplicateServiceImpl
 * @Description 174查询影响图片地址实现类
 * @Author linjj
 * @Date 2023/5/12 15:55
 * @Version 1.0
 */
@Service
public class DuplicateServiceImpl extends ServiceImpl<QualityMapper, FliePath> implements DuplicateService {
    @Autowired
    CommomtableMapper commomtableMapper;
    @Value("${waterPicPath}")
    private String waterPicPath;

    @Value("${EMR_RECORD_JSP}")
    private String EMRRECORDJSP;

    @Autowired
    QualityMapper qualityMapper;

    @Override
    public List<DuplicateVo> getFilePath(String inpatientNo, Integer admissTimes) {
        //定义返回数据集合
        List<DuplicateVo> list = new ArrayList<>();
        //根据住院号住院次数查询分段
        List<CommomtableVo> zdAssort = commomtableMapper.getZdAssort(inpatientNo, admissTimes);
        //根据分段查询路径
        for (CommomtableVo assortIdList : zdAssort) {
            String assortId = assortIdList.getAssortId();
            //查询对应分类文件路径
            List<String> commomtable = commomtableMapper.getCommomtable(inpatientNo, admissTimes, assortId);
            //获取该分类标题、页数
            PageCountVo pageCount = commomtableMapper.getPageCount(inpatientNo, admissTimes, assortId);
            String join = StringUtils.join(commomtable, ",");
            List<String> imageUrllist = Arrays.asList(join.split(","));
            //使用yyyyMMddHHmmssSSS格式作为文件名
            Date date = new Date();
            SimpleDateFormat format = new SimpleDateFormat("yyyyMMddHHmmssSSS");
            String newDate = format.format(date);
            imageToPdf(imageUrllist, waterPicPath, newDate);
            String outSrc = EMRRECORDJSP + newDate + ".pdf";
            DuplicateVo duplicateVo = new DuplicateVo();
            duplicateVo.setTitle(pageCount.getAssortName());
            duplicateVo.setAssortName(pageCount.getAssortName());
            duplicateVo.setPageCount(pageCount.getPageCount());
            duplicateVo.setPdfUrl(outSrc);
            list.add(duplicateVo);
        }
        return list;
    }


    /**
     * imageUrllist：图片路径集合，
     * mOutputPdfFileName：pdf输出位置
     *
     * @param imageUrllist
     * @param waterPicPath
     * @return
     */
    public static File imageToPdf(List<String> imageUrllist, String waterPicPath, String newDate) {
        if (!new File(waterPicPath).isDirectory()) {
            new File(waterPicPath).mkdirs();
        }
        Document document = new Document(PageSize.A4, 0, 0, 0, 0); //创建文档容器
        try {
            PdfWriter.getInstance(document, new FileOutputStream(waterPicPath + "\\" + newDate + ".pdf"));
            document.open();
            for (int i = 0; i < imageUrllist.size(); i++) {
                document.newPage();
//                doc.add(new Paragraph("简单使用iText"));
                Image png1 = Image.getInstance(imageUrllist.get(i));
                float heigth = png1.getHeight();
                float width = png1.getWidth();
                int percent = getPercent2(heigth, width);
                png1.setAlignment(Image.MIDDLE);
                png1.scalePercent(percent + 3);// 表示是原来图像的比例;
                document.add(png1);
            }

        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (DocumentException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            document.close();
        }
        File mOutputPdfFile = new File(waterPicPath);
        if (!mOutputPdfFile.exists()) {
            mOutputPdfFile.deleteOnExit();
            return null;
        }
        return mOutputPdfFile;
    }

    private static int getPercent2(float h, float w) {
        int p = 0;
        float p2 = 0.0f;
        p2 = 530 / w * 100;
        p = Math.round(p2);
        return p;
    }

    private String selectRootByNotWater(String srcPath) {
        //获取盘符
        String str = srcPath.substring(0, 1).toUpperCase();
        switch (str) {
            case "C":
                return "reloadC\\";
            case "D":
                return "reloadD\\";
            case "E":
                return "reloadE\\";
            case "F":
                return "reloadF\\";
            case "G":
                return "reloadG\\";
            case "H":
                return "reloadH\\";
            case "I":
                return "reloadI\\";
            case "J":
                return "reloadJ\\";
            case "K":
                return "reloadK\\";
            default:
                ;
        }
        return null;
    }


    @Override
    public String SeniorExamine(String startRange, String endRange) {
        //获取时间段内的病例
        //查600w条
        List<FliePath> fliePaths = qualityMapper.getPhAndFliePath(startRange, endRange);
        //将600w根据patientId进行分组，key=10w个
        Map<String, List<FliePath>> collect = fliePaths.stream().collect(Collectors.groupingBy(FliePath::getPatientId));
        //保存错误信息
        List<FliePath> errors = new ArrayList<>();
        for (String k : collect.keySet()) {
            List<FliePath> v = collect.get(k);//总共600w图片路径
            v.forEach(p -> {
                ImageIcon imageIcon = new ImageIcon(p.getFliePath());
                //获取图片宽度无法获取图片损坏
                if (imageIcon.getIconHeight() == -1) {
                    errors.add(p);//损坏的图片路径存放
                }
            });
        }
        super.saveBatch(errors, 1);
        return "完成";
    }


}
