package com.example.duplicate.service.impl;

import com.example.duplicate.controller.vo.*;
import com.example.duplicate.infrastructure.configOneDao.ArchiveDetailMapper;
import com.example.duplicate.infrastructure.configOneDao.ArchiveMasterMapper;
import com.example.duplicate.infrastructure.configOneDao.CommomtableMapper;
import com.example.duplicate.infrastructure.configOneDao.LzRmMapper;
import com.example.duplicate.service.LzRmService;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

/**
 * @ClassName LzRmServiceImpl
 * @Description
 * @Author linjj
 * @Date 2023/11/10 15:42
 * @Version 1.0
 */
@Service
@Slf4j
public class LzRmServiceImpl implements LzRmService {


    @Resource
    private LzRmMapper lzRmMapper;
    @Resource
    private ArchiveMasterMapper archiveMasterMapper;
    @Resource
    private ArchiveDetailMapper archiveDetailMapper;
    @Resource
    private CommomtableMapper commomtableMapper;

    private static SimpleDateFormat inSDF = new SimpleDateFormat("yyyy.mm.dd");
    private static SimpleDateFormat outSDF = new SimpleDateFormat("yyyy-mm-dd");

    @Override
    public int LzRmSplit() {
        //新增状态
        int addStatic = 0;
        //查询需要处理记录
        List<CommomtableCopyVo> CommomtableCopyList = lzRmMapper.getCommomtableCopyInfo();
        //根据住院号盘号查询影像信息
        for (CommomtableCopyVo list : CommomtableCopyList) {
            String LockInfo = list.getPh();
            String phString = list.getPhString();
            String pageNumber = list.getPageNumber();
            String inpatientNoPast = String.format("%010d", Integer.parseInt(list.getInpatientNoPast()));
            //页码不存在跳出当前循环
            if (StringUtils.isBlank(pageNumber)) {
                log.info("-------旧住院号：" + inpatientNoPast + "盘号:" + LockInfo + "新住院号:" + list.getInpatientNo() + "的病案页码为空-----------------");
                lzRmMapper.updateSynchronousTime(2,list.getInpatientNoPast(), phString, pageNumber);
                continue;
            }
            //截取第一个数
            String assortName = intercept(list.getPageNumber());
            List<ZdAssortVo> zdAssorList = lzRmMapper.getZdAssortInfo(inpatientNoPast, LockInfo, assortName);
            if (zdAssorList.isEmpty()) {
                log.info("----------------旧住院号：" + inpatientNoPast + "盘号:" + LockInfo + "页码:" + assortName + "的病案不存在---------------------");
                lzRmMapper.updateSynchronousTime(3,list.getInpatientNoPast(), phString, pageNumber);
                continue;
            }
            //插入一条数据到Archive_Master表跟Archive_Detail表
            addStatic = add(list, zdAssorList);
            //修改状态
            lzRmMapper.updateSynchronousTime(1,list.getInpatientNoPast(), phString, pageNumber);
        }

        return addStatic;
    }

    /**
     * @description: 插入一条数据到Archive_Master表
     * @params: commomtableCopyVo
     * @params: zdAssorList
     * @return: addArchiveMasterVo
     * @author linjj
     * @date: 2023/11/13 14:58
     */
    private int add(CommomtableCopyVo commomtableCopyVo, List<ZdAssortVo> zdAssorList) {
        //新增文件表状态
        int addDetailStatic = 0;
        //新增comm表状态
        int addAddLzRmCommStatic = 0;
        //使用时间生成一个id
        SimpleDateFormat fmt = new SimpleDateFormat("yyyyMMddHHmmssSSS");
        //获取今天日期
        String id = fmt.format(new Date());
        //转换不规则时间字符串
        String s = formatDate(commomtableCopyVo.getDisDate());
        ZdAssortVo zdAssortVo = zdAssorList.get(0);
        AddArchiveMasterVo addArchiveMasterVo = new AddArchiveMasterVo();
        addArchiveMasterVo.setID(id);
        addArchiveMasterVo.setPatientId(commomtableCopyVo.getInpatientNo());
        addArchiveMasterVo.setInpNo(commomtableCopyVo.getInpatientNo());
        addArchiveMasterVo.setVisitId(commomtableCopyVo.getAdmissTimes());
        addArchiveMasterVo.setName(commomtableCopyVo.getName());
        addArchiveMasterVo.setDeptName(commomtableCopyVo.getDisDept());
        addArchiveMasterVo.setDischargeDateTime(s);
        addArchiveMasterVo.setArchiveState("缩微");
        addArchiveMasterVo.setAdmissionDateTime(s);
        addArchiveMasterVo.setLockInfo(commomtableCopyVo.getPh());
        addArchiveMasterVo.setDISCHARGEDISPOSITION(zdAssortVo.getDISCHARGEDISPOSITION());
        addArchiveMasterVo.setSplitName("Ljj");
        int i = archiveMasterMapper.addArchiveMaster(addArchiveMasterVo);
        //插入文件表数据
        if (i == 1) {
            AddArchiveDetail addArchiveDetail = new AddArchiveDetail();
            //使用时间生成一个id
            SimpleDateFormat detailFmt = new SimpleDateFormat("yyyyMMddHHmmssSSS");
            //获取今天日期
            String detailId = detailFmt.format(new Date());
            addArchiveDetail.setID(detailId);
            addArchiveDetail.setPDFPATH(zdAssortVo.getPDFPATH());
            addArchiveDetail.setMasterID(id);
            addArchiveDetail.setUpLoadDateTime(zdAssortVo.getUpLoadDateTime());
            addArchiveDetail.setAssortID(zdAssortVo.getAssortId());
            addArchiveDetail.setSource("缩微");
            addArchiveDetail.setFlag(zdAssortVo.getFlag());
            addArchiveDetail.setSys(zdAssortVo.getSys());
            addArchiveDetail.setSplitName("Ljj");
            addDetailStatic = archiveDetailMapper.addArchiveDetail(addArchiveDetail);
            //向commomtable表增加数据
            if (addDetailStatic == 1) {
                AddLzRmCommVo addLzRmCommVo = new AddLzRmCommVo();
                addLzRmCommVo.setPatientId(id);
                addLzRmCommVo.setAdmissId(commomtableCopyVo.getInpatientNo());
                addLzRmCommVo.setAdmissTimes(commomtableCopyVo.getAdmissTimes());
                addLzRmCommVo.setInpatientNo(commomtableCopyVo.getInpatientNo());
                addLzRmCommVo.setName(commomtableCopyVo.getName());
                addLzRmCommVo.setDisDate(s);
                addLzRmCommVo.setDisDeptName(commomtableCopyVo.getDisDept());
                addLzRmCommVo.setPh(commomtableCopyVo.getPh());
                addLzRmCommVo.setGdh(commomtableCopyVo.getPh());
                addLzRmCommVo.setSplitName("Ljj");
                addAddLzRmCommStatic = commomtableMapper.addAddLzRmComm(addLzRmCommVo);
            }

        }
        return addAddLzRmCommStatic;
    }

    /**
     * @description: 按照规则截取
     * @params: pageNumber
     * @return: assortName
     * @author linjj
     * @date: 2023/11/13 14:57
     */
    private String intercept(String pageNumber) {
        //如果包含--就截取--前
        if (pageNumber.contains("--")) {
            pageNumber = pageNumber.substring(0, pageNumber.indexOf("--"));
            return pageNumber;
        }
        //如果包含-就截取-前
        if (pageNumber.contains("-")) {
            pageNumber = pageNumber.substring(0, pageNumber.indexOf("-"));
            return pageNumber;
        }
        return pageNumber;
    }


    /**
     * @description: 转换不规则时间字符串
     * @params: inDate
     * @return: outDate
     * @author linjj
     * @date: 2023/11/13 15:13
     */
    public static String formatDate(String inDate) {
        String outDate = "";
        if (inDate != null) {
            try {
                Date date = inSDF.parse(inDate);
                outDate = outSDF.format(date);
            } catch (ParseException ex) {
            }
        }
        return outDate;
    }

}
