package com.example.duplicate.service.impl;


import com.example.duplicate.controller.vo.ArchiveMasterVo;
import com.example.duplicate.controller.vo.MessageLog;
import com.example.duplicate.controller.vo.MessageSubordinate;
import com.example.duplicate.controller.vo.MessageSubordinateVo;
import com.example.duplicate.infrastructure.configOneDao.ArchiveMasterMapper;
import com.example.duplicate.infrastructure.configOneDao.MessageLogMapper;
import com.example.duplicate.infrastructure.configOneDao.MessageSubordinateMapper;
import com.example.duplicate.infrastructure.configTwoDao.MessageLogTwoMapper;
import com.example.duplicate.infrastructure.configTwoDao.MessageSubordinateTwoMapper;
import com.example.duplicate.service.MessageSubordinateService;
import com.example.utils.ListUtilsNew;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.collections4.ListUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;

import java.util.List;


/**
 * @ClassName ZJYYServiceImpl
 * @Description 湛江医院接口实现类
 * @Author linjj
 * @Date 2023/10/13 13:50
 * @Version 1.0
 */
@Service
@Slf4j
public class MessageSubordinateServiceImpl implements MessageSubordinateService {

    static final Logger logger = LoggerFactory.getLogger(MessageSubordinateServiceImpl.class);

    @Value("${ZJ_DATE_TIME_MESSAGE}")
    private String dateTime;
    @Autowired
    MessageSubordinateMapper messageSubordinateMapper;
    @Autowired
    MessageSubordinateTwoMapper messageSubordinateTwoMapper;
    @Autowired
    ArchiveMasterMapper archiveMasterMapper;
    @Autowired
    MessageLogMapper messageLogMapper;
    @Autowired
    MessageLogTwoMapper messageLogTwoMapper;


    @Override
    public int delMessage() {
        //查询需要删除数据条数
        int messageNum = messageSubordinateMapper.getMessageNum(dateTime);
        //需要次数
        double num = ((double) messageNum) / 100;
        int circulateNum = (int) Math.ceil(num);
        for (int i = 0; i < circulateNum; i++) {
            //查询需要删除数据的id每次查100条
            List<MessageSubordinateVo> list = messageSubordinateMapper.getAllByIds();
            //id集合
            List<String> idList = ListUtilsNew.distinctSelect(list, MessageSubordinateVo::getId);
            //转成逗号拼接
            String ids = String.join(",", idList);
            messageSubordinateMapper.del(ids);
        }
        return 1;
    }

    @Override
    public int addMessage() {
        //查询一共有多少份病历需要同步
        int masterIdNum = archiveMasterMapper.masterIdNum(dateTime);
        //需要次数
        double num = ((double) masterIdNum) / 100;
        //少数往前进1确保不丢失数据
        int circulateNum = (int) Math.ceil(num);
        for (int i = 0; i < circulateNum; i++) {
            //每次查询100份病历
            List<ArchiveMasterVo> masterId = archiveMasterMapper.getMasterId(dateTime);
            if (masterId.size() == 0) {
                return 0;
            }
            //masterId集合
            List<String> idList = ListUtilsNew.distinctSelect(masterId, ArchiveMasterVo::getId);
            //转成逗号拼接
            String masterIds = String.join(",", idList);
            //根据masterId查询message_log表
            List<MessageLog> messageLogList = messageLogMapper.getAllByMasterId(masterIds);
            //获取message_log表id集合
            List<String> messageLogId = ListUtilsNew.distinctSelect(messageLogList, MessageLog::getId);
            //如果档次100条记录没有messageLogId那么保存记录后结束本次循环
            if (messageLogId.size() == 0) {
                //保存处理过的masterId
                archiveMasterMapper.add(idList);
                continue;
            }
            //根据message_log表id操作message_subordinate表
            messageSubordinate(messageLogId);
            //操作完message_subordinate表操作message_log表
            messageLog(messageLogList);
            //保存处理过的masterId
            archiveMasterMapper.add(idList);
        }
        return 0;
    }

    private void messageSubordinate(List<String> messageLogId) {
        //分批次
        List<List<String>> newList = ListUtils.partition(messageLogId, 100);
        for (List<String> messageList : newList) {
            //转成字符串类型逗号拼接
            String messageLogIds = String.join(",", messageList);
            //查询100条
            List<MessageSubordinate> list = messageSubordinateMapper.getAllByMessageLogId(messageLogIds);
            if (list.size()==0){
                continue;
            }
            //往新表插入
            messageSubordinateTwoMapper.addAll(list);
            //新表插入完成删除旧表
            messageSubordinateMapper.del(messageLogIds);
        }
    }

    private void messageLog(List<MessageLog> messageLogList) {
        List<List<MessageLog>> newList = ListUtils.partition(messageLogList, 100);
        for (List<MessageLog> messageList : newList) {
            //往新表中拆入数据
            messageLogTwoMapper.addAll(messageList);
            //获取这100条message_log表id集合
            List<String> ids = ListUtilsNew.distinctSelect(messageList, MessageLog::getId);
            //移除旧表数据
            String messageLogIds = String.join(",", ids);
            messageLogMapper.del(messageLogIds);
        }


    }

}
